summaryrefslogtreecommitdiffstats
path: root/kjsembed/bindings/dcop_imp.h
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/bindings/dcop_imp.h')
-rw-r--r--kjsembed/bindings/dcop_imp.h30
1 files changed, 15 insertions, 15 deletions
diff --git a/kjsembed/bindings/dcop_imp.h b/kjsembed/bindings/dcop_imp.h
index ca20fdca..8b186e72 100644
--- a/kjsembed/bindings/dcop_imp.h
+++ b/kjsembed/bindings/dcop_imp.h
@@ -48,19 +48,19 @@ class JSDCOPInterfacerLoader : public JSBindingBase
};
/**
* TTQObject Binding for a DCOP interface
*/
class JSDCOPInterface : public BindingObject, public DCOPObject
{
Q_OBJECT
public:
- JSDCOPInterface( KJS::Interpreter *js, TTQObject *parent, const char *name=0 );
+ JSDCOPInterface( KJS::Interpreter *js, TQObject *parent, const char *name=0 );
virtual ~JSDCOPInterface();
TQCStringList functionsDynamic();
- bool processDynamic (const TTQCString &fun, const TTQByteArray &data, TTQCString &replyType, TTQByteArray &replyData);
+ bool processDynamic (const TQCString &fun, const TQByteArray &data, TQCString &replyType, TQByteArray &replyData);
public slots:
- void publish(const TTQString& signature);
+ void publish(const TQString& signature);
private:
TQCStringList m_Members;
@@ -123,23 +123,23 @@ public:
/** Invokes the call function. */
virtual KJS::Value call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args );
- static KJS::Value demarshall( KJS::ExecState * exec, const TTQCString& type, TTQDataStream& data);
- static TTQVariant demarshall( const TTQCString &type, TTQDataStream &ds);
- static void marshall( const TTQVariant& data, const TTQString &typeName, TTQByteArray& buffer );
- static TTQStringList getTypes( const TTQString& function);
+ static KJS::Value demarshall( KJS::ExecState * exec, const TQCString& type, TQDataStream& data);
+ static TQVariant demarshall( const TQCString &type, TQDataStream &ds);
+ static void marshall( const TQVariant& data, const TQString &typeName, TQByteArray& buffer );
+ static TQStringList getTypes( const TQString& function);
bool attach() const;
bool detach() const;
bool isAttached() const;
- TTQString dcopStart( const TTQString& appName, const TTQStringList& args);
- TTQStringList registeredApplications();
- TTQStringList remoteObjects( const TTQString& remApp);
- TTQStringList remoteInterfaces( const TTQString& remApp, const TTQString& remObj );
- TTQStringList remoteFunctions( const TTQString& remApp, const TTQString& remObj);
- bool connectDCOPSignal (const TTQString &sender, const TTQString &senderObj, const TTQString &signal, const TTQString &receiverObj, const TTQString &slot, bool Volatile = false);
- bool disconnectDCOPSignal (const TTQString &sender, const TTQString &senderObj, const TTQString &signal, const TTQString &receiverObj, const TTQString &slot);
+ TQString dcopStart( const TQString& appName, const TQStringList& args);
+ TQStringList registeredApplications();
+ TQStringList remoteObjects( const TQString& remApp);
+ TQStringList remoteInterfaces( const TQString& remApp, const TQString& remObj );
+ TQStringList remoteFunctions( const TQString& remApp, const TQString& remObj);
+ bool connectDCOPSignal (const TQString &sender, const TQString &senderObj, const TQString &signal, const TQString &receiverObj, const TQString &slot, bool Volatile = false);
+ bool disconnectDCOPSignal (const TQString &sender, const TQString &senderObj, const TQString &signal, const TQString &receiverObj, const TQString &slot);
KJS::Value dcopCall(KJS::ExecState *exec, KJS::Object &, const KJS::List &args);
KJS::Value dcopSend(KJS::ExecState *exec, KJS::Object &, const KJS::List &args);
private:
@@ -48,19 +48,19 @@ class JSDCOPInterfacerLoader : public JSBindingBase
};
/**
-* TTQObject Binding for a DCOP interface
+* TQObject Binding for a DCOP interface
*/
class JSDCOPInterface : public BindingObject, public DCOPObject